@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dag-draw" "1.0.4"
+(define-package "dag-draw" "20251117.1418"
   "Draw directed graphs using the GKNV algorithm."
   '((emacs "26.1")
     (dash  "2.19.1")
     (ht    "2.3"))
   :url "https://codeberg.org/trevoke/dag-draw.el"
-  :commit "0c10afdff9f1ebfeea242e921fa22bb385cdf899"
-  :revdesc "0c10afdff9f1"
+  :commit "d7e004b32e06073d09b67cab7086695cce7f690d"
+  :revdesc "d7e004b32e06"
   :keywords '("tools" "extensions"))
