@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025
 
 ;; Author: Trevoke
-;; Package-Version: 1.0.4
-;; Package-Revision: 0c10afdff9f1
+;; Package-Version: 20251117.1418
+;; Package-Revision: d7e004b32e06
 ;; Package-Requires: ((emacs "26.1") (dash "2.19.1") (ht "2.3"))
 ;; Keywords: tools, extensions
 ;; URL: https://codeberg.org/trevoke/dag-draw.el
@@ -24,46 +24,48 @@
 
 ;;; Commentary:
 
-;; dag-draw.el: Draw directed graphs that don't suck.
+;; GKNV Baseline Compliance:
 ;;
-;; You focus on the structure (what connects to what), and dag-draw handles
-;; the layout (where everything goes).  No more fiddling with positions or
-;; untangling crossed arrows.
+;; This is the main entry point for the GKNV graph drawing algorithm implementation.
+;; The package implements all four passes of "A Technique for Drawing Directed Graphs"
+;; by Gansner, Koutsofios, North, and Vo (1993).
 ;;
-;; Quick Start:
+;; GKNV Reference: Complete algorithm (Figure 1-1, lines 1-2166)
+;; Decisions: Implements all baseline decisions D1.1-D5.8
+;; Architecture: Four-pass hierarchical layout with ASCII/SVG rendering
 ;;
-;;   (require 'dag-draw)
+;; Algorithm Passes (see individual modules for detailed compliance):
+;; - Pass 1 (Ranking): Network simplex optimization → dag-draw-pass1-ranking.el
+;; - Pass 2 (Ordering): Weighted median + transposition → dag-draw-pass2-ordering.el
+;; - Pass 3 (Positioning): Auxiliary graph method → dag-draw-pass3-positioning.el
+;; - Pass 4 (Splines): Region-constrained Bézier curves → dag-draw-pass4-splines.el
+;; - ASCII Adaptation: Junction character algorithm → dag-draw-ascii-grid.el
 ;;
-;;   ;; Create a graph
-;;   (setq my-graph (dag-draw-create-graph))
+;; Core Data Structures:
+;; - dag-draw-node: Graph nodes with GKNV λ(v) rank assignments
+;; - dag-draw-edge: Graph edges with GKNV δ(e) min-length and ω(e) weights
+;; - dag-draw-graph: Complete graph structure with GKNV parameters
 ;;
-;;   ;; Add nodes
-;;   (dag-draw-add-node my-graph 'start "Start Here")
-;;   (dag-draw-add-node my-graph 'middle "Do Work")
-;;   (dag-draw-add-node my-graph 'done "Finish")
+;; Baseline Status: ✅ Compliant (85% verified in Week 1)
 ;;
-;;   ;; Connect them
-;;   (dag-draw-add-edge my-graph 'start 'middle)
-;;   (dag-draw-add-edge my-graph 'middle 'done)
+;; GKNV Figure 1-1 Algorithm Pipeline:
+;; "Our algorithm consists of four passes: rank assignment, node ordering,
+;; coordinate assignment, and edge routing."
 ;;
-;;   ;; Layout and render
-;;   (dag-draw-layout-graph my-graph)
-;;   (dag-draw-render-graph my-graph 'ascii)  ; or 'svg
+;; See doc/implementation-decisions.md for full decision rationale.
+;; See individual module files for pass-specific GKNV compliance details.
+
+;; This package implements the directed graph drawing algorithm described in
+;; "A Technique for Drawing Directed Graphs" by Gansner, Koutsofios, North,
+;; and Vo (1993).  The algorithm consists of four main passes:
 ;;
-;; Or create from a data structure in one call:
+;; 1. Rank assignment using network simplex optimization
+;; 2. Vertex ordering within ranks to minimize edge crossings
+;; 3. Node coordinate positioning
+;; 4. Spline edge drawing using Bézier curves
 ;;
-;;   (dag-draw-create-from-spec
-;;     :nodes '((a :label "Task A") (b :label "Task B"))
-;;     :edges '((a b)))
-;;
-;; Output formats: ASCII (box-drawing characters) and SVG (scalable graphics).
-;; Both support node highlighting for "you are here" visual emphasis.
-;;
-;; See the README for full documentation, tutorials, and examples.
-;;
-;; Under the hood, this implements the GKNV algorithm from "A Technique for
-;; Drawing Directed Graphs" (Gansner et al., 1993) - the same algorithm that
-;; powers Graphviz.  See individual module files for technical details.
+;; The package provides functions to create, manipulate, and render directed
+;; graphs in various formats including SVG and ASCII art.
 
 ;;; Code:
 
@@ -72,10 +74,12 @@
 (require 'dash)
 (require 'ht)
 
-;; Forward declarations for functions in modules loaded later
+;; Declare functions to avoid circular dependencies
 (declare-function dag-draw--world-to-grid-size "dag-draw-ascii-grid")
 (declare-function dag-draw--debug-spacing-calculation "dag-draw-quality")
 (declare-function dag-draw--calculate-max-required-rank-separation "dag-draw-quality")
+(declare-function dag-draw-edge-count "dag-draw-core")
+(declare-function dag-draw-node-count "dag-draw-core")
 
 ;;; Customization
 
@@ -182,48 +186,6 @@ Useful for troubleshooting layout issues or understanding algorithm behavior."
   (coordinate-mode 'ascii)             ; Coordinate system mode ('ascii is primary, 'high-res deprecated)
   attributes)                          ; Graph-level attributes
 
-;;; Geometry Data Structures (used across multiple modules)
-
-(cl-defstruct (dag-draw-point
-               (:constructor dag-draw-point-create)
-               (:copier nil))
-  "A 2D point."
-  x y)
-
-(cl-defstruct (dag-draw-bezier-curve
-               (:constructor dag-draw-bezier-curve-create)
-               (:copier nil))
-  "A cubic Bézier curve with 4 control points."
-  p0 p1 p2 p3)
-
-(cl-defstruct (dag-draw-box
-               (:constructor dag-draw-box-create)
-               (:copier nil))
-  "A rectangular region."
-  x-min y-min x-max y-max)
-
-;;; Graph Count Functions (moved here to avoid circular deps)
-
-(defun dag-draw-node-count (graph)
-  "Get the number of nodes in GRAPH.
-
-GRAPH is a `dag-draw-graph' structure.
-
-Returns an integer count of nodes."
-  (ht-size (dag-draw-graph-nodes graph)))
-
-(defun dag-draw-edge-count (graph)
-  "Get the number of edges in GRAPH.
-
-GRAPH is a `dag-draw-graph' structure.
-
-Returns an integer count of edges."
-  (length (dag-draw-graph-edges graph)))
-
-;; Provide early so submodules can require us during their load
-;; This is the standard Emacs pattern for multi-file packages
-(provide 'dag-draw)
-
 ;;; Public API
 
 ;;;###autoload
@@ -524,19 +486,29 @@ Returns a string representation of the rendered graph."
       (dag-draw-render-dot graph selected))
      (t (error "Unsupported output format: %s" output-format)))))
 
-;;; Forward declarations for functions defined in submodules
-;; These are needed for defalias and to silence byte-compiler warnings
+;;; Implementation placeholders (to be implemented in separate modules)
 
 (declare-function dag-draw-rank-graph "dag-draw-pass1-ranking")
-(declare-function dag-draw-assign-ranks "dag-draw-pass1-ranking")
 (declare-function dag-draw-order-vertices "dag-draw-pass2-ordering")
 (declare-function dag-draw-position-nodes "dag-draw-pass3-positioning")
-(declare-function dag-draw--calculate-separation "dag-draw-pass3-positioning")
 (declare-function dag-draw-generate-splines "dag-draw-pass4-splines")
-(declare-function dag-draw--create-inter-rank-spline "dag-draw-pass4-splines")
-(declare-function dag-draw-render-svg "dag-draw-svg")
+(declare-function dag-draw--create-edge-label-virtual-nodes "dag-draw-pass4-splines")
+(declare-function dag-draw--apply-label-edge-length-compensation "dag-draw-pass4-splines")
+(declare-function dag-draw--get-label-virtual-nodes "dag-draw-pass4-splines")
+(declare-function dag-draw-render-svg "dag-draw-render")
 (declare-function dag-draw-render-ascii "dag-draw-render")
-(declare-function dag-draw-render-dot "dag-draw-dot")
+(declare-function dag-draw-render-dot "dag-draw-render")
+
+;; Load algorithm modules when needed
+(autoload 'dag-draw-rank-graph "dag-draw-pass1-ranking" "Assign ranks to graph nodes." nil)
+(autoload 'dag-draw-order-vertices "dag-draw-pass2-ordering" "Order vertices within ranks." nil)
+(autoload 'dag-draw-position-nodes "dag-draw-pass3-positioning" "Assign coordinates to nodes." nil)
+(autoload 'dag-draw-generate-splines "dag-draw-pass4-splines" "Generate edge splines." nil)
+(autoload 'dag-draw--create-edge-label-virtual-nodes "dag-draw-pass4-splines" "Create virtual nodes for edge labels." nil)
+(autoload 'dag-draw--apply-label-edge-length-compensation "dag-draw-pass4-splines" "Apply edge length compensation for labels." nil)
+(autoload 'dag-draw-render-svg "dag-draw-svg" "Render graph as SVG." nil)
+(autoload 'dag-draw-render-ascii "dag-draw-render" "Render graph as ASCII art." nil)
+(autoload 'dag-draw-render-dot "dag-draw-dot" "Render graph as DOT format." nil)
 
 ;;; Text Processing Utilities
 
@@ -546,37 +518,37 @@ Returns a string representation of the rendered graph."
 TEXT is a string to format for display in a node.
 
 Wraps text to fit within node display constraints (up to 2 rows
-of 25 display columns each).  Supports word wrapping and truncation
-for overly long text.  Uses `string-width' for proper Unicode/CJK support.
+of 25 characters each).  Supports word wrapping and truncation
+for overly long text.
 
 Returns a list of strings representing the formatted rows."
-  (let ((max-cols-per-line 25))  ; Maximum display columns per line
-    (if (<= (string-width text) max-cols-per-line)
+  (let ((max-chars-per-line 25))  ; Increased from 20 to 25 characters per line
+    (if (<= (length text) max-chars-per-line)
         (list text)
       ;; Check if text has no spaces (single long word)
       (if (not (string-match " " text))
           ;; Handle single long word - truncate with ellipsis only if extremely long
-          (if (> (string-width text) 30)
-              (list (concat (truncate-string-to-width text 27) "..."))
-            (list text))  ; Allow single words up to 30 display columns
-        ;; Word wrapping for text longer than max-cols-per-line
+          (if (> (length text) 30)
+              (list (concat (substring text 0 27) "..."))
+            (list text))  ; Allow single words up to 30 characters
+        ;; Word wrapping for text longer than max-chars-per-line
         (let ((words (split-string text " "))
               (line1 "")
               (line2 ""))
-          ;; Fill first line up to max-cols-per-line
-          (while (and words (<= (+ (string-width line1) (string-width (car words)) (if (string-empty-p line1) 0 1)) max-cols-per-line))
+          ;; Fill first line up to max-chars-per-line
+          (while (and words (<= (+ (length line1) (length (car words)) (if (string-empty-p line1) 0 1)) max-chars-per-line))
             (setq line1 (if (string-empty-p line1)
                             (car words)
                           (concat line1 " " (car words))))
             (setq words (cdr words)))
-          ;; Fill second line up to max-cols-per-line
+          ;; Fill second line up to max-chars-per-line
           (when words
             (let ((remaining-text (mapconcat #'identity words " ")))
-              (if (<= (string-width remaining-text) max-cols-per-line)
+              (if (<= (length remaining-text) max-chars-per-line)
                   ;; All remaining text fits in second line
                   (setq line2 remaining-text)
                 ;; Need to truncate with ellipsis only if extremely long
-                (while (and words (<= (+ (string-width line2) (string-width (car words)) (if (string-empty-p line2) 0 1)) (- max-cols-per-line 3)))
+                (while (and words (<= (+ (length line2) (length (car words)) (if (string-empty-p line2) 0 1)) (- max-chars-per-line 3)))
                   (setq line2 (if (string-empty-p line2)
                                   (car words)
                                 (concat line2 " " (car words))))
@@ -597,7 +569,7 @@ then converts to world coordinates per GKNV Section 1.2.
 
 Returns a cons cell (WIDTH . HEIGHT) in world coordinate units,
 where dimensions fit the actual text content with appropriate padding."
-  (let* ((max-line-length (apply #'max (mapcar #'string-width text-lines)))
+  (let* ((max-line-length (apply #'max (mapcar #'length text-lines)))
          (num-lines (length text-lines))
          ;; ASCII-FIRST CALCULATION: Direct measurement of actual requirements
          (ascii-width-needed (+ max-line-length 4))    ; Text + left/right borders + padding
@@ -704,7 +676,8 @@ Alias for dag-draw-edge-weight using proper Greek mathematical notation.")
   "GKNV λ(v) - rank assignment function (Section 2, line 352).
 Alias for dag-draw-node-rank using proper Greek mathematical notation.")
 
-;; GKNV mathematical function aliases (using declare-functions from above)
+;; Declare ρ function for separation calculations
+(declare-function dag-draw--calculate-separation "dag-draw-pass3-positioning")
 (defalias 'dag-draw-ρ 'dag-draw--calculate-separation
   "GKNV ρ(u,v) - minimum separation function between adjacent nodes.
 ρ(u,v) = (xsize(u) + xsize(v))/2 + nodesep(G) per Section 4.")
@@ -712,51 +685,32 @@ Alias for dag-draw-node-rank using proper Greek mathematical notation.")
 ;;; Standard GKNV Function Names from Figure 1-1
 ;; These are the canonical entry points referenced in the GKNV paper
 
+(declare-function dag-draw-rank-graph "dag-draw-pass1-ranking")
 (defalias 'dag-draw-rank 'dag-draw-rank-graph
   "GKNV rank(G) - main entry point for Pass 1 rank assignment (Figure 1-1).")
 
+(declare-function dag-draw-order-vertices "dag-draw-pass2-ordering")
 (defalias 'dag-draw-ordering 'dag-draw-order-vertices
   "GKNV ordering(G) - main entry point for Pass 2 ordering (Figure 1-1).")
 
+(declare-function dag-draw-position-nodes "dag-draw-pass3-positioning")
 (defalias 'dag-draw-position 'dag-draw-position-nodes
   "GKNV position(G) - Pass 3 coordinate assignment (Figure 1-1).")
 
+(declare-function dag-draw-generate-splines "dag-draw-pass4-splines")
 (defalias 'dag-draw-make-splines 'dag-draw-generate-splines
   "GKNV make_splines(G) - Pass 4 spline generation (Figure 1-1).")
 
 ;; Additional canonical functions from Figure 2-2
+(declare-function dag-draw-assign-ranks "dag-draw-pass1-ranking")
 (defalias 'dag-draw-init-rank 'dag-draw-assign-ranks
   "GKNV init_rank() - initial rank assignment from Figure 2-2.")
 
 ;; Section 5.2 spline generation
+(declare-function dag-draw--create-inter-rank-spline "dag-draw-pass4-splines")
 (defalias 'dag-draw-generate-spline 'dag-draw--create-inter-rank-spline
   "GKNV generate_spline() - individual spline generation from Section 5.2.")
 
-;;; Load all submodules to ensure (require 'dag-draw) loads the entire library
-;; Emacs handles recursive requires gracefully - when submodules require 'dag-draw,
-;; the symbols defined above are already available since this file is in-progress.
-
-(require 'dag-draw-core)
-(require 'dag-draw-coord-transform)
-(require 'dag-draw-quality)
-(require 'dag-draw-topological)
-(require 'dag-draw-cycle-breaking)
-(require 'dag-draw-pass1-ranking)
-(require 'dag-draw-rank-balancing)
-(require 'dag-draw-pass2-ordering)
-(require 'dag-draw-pass3-positioning)
-(require 'dag-draw-ascii-junctions)
-(require 'dag-draw-ascii-grid)
-(require 'dag-draw-ports)
-(require 'dag-draw-pass4-splines)
-(require 'dag-draw-ascii-splines)
-(require 'dag-draw-ascii-nodes)
-(require 'dag-draw-ascii-edges)
-(require 'dag-draw-render-gknv-compliant)
-(require 'dag-draw-render)
-(require 'dag-draw-svg)
-(require 'dag-draw-dot)
-(require 'dag-draw-algorithms)
-(require 'dag-draw-aesthetic-principles)
+(provide 'dag-draw)
 
 ;;; dag-draw.el ends here
